Error types for the Typecast SDK
This module contains all error types that can be returned by the SDK.
Enums
- Typecast
Error - Error type for Typecast API operations
Type Aliases
- Result
- Result type alias for Typecast operations
Error types for the Typecast SDK
This module contains all error types that can be returned by the SDK.