Data models for the Typecast API
This module contains all the data structures used for API requests and responses.
Structs
- Credits
- Credit usage information
- Custom
Voice - A custom (user-cloned) voice returned by the clone-voice endpoint
- Error
Response - API error response
- Generate
ToFile Request - Convenience request for generating audio directly to a file.
- Limits
- Usage limit information
- Model
Info - Model information with supported emotions
- Output
- Audio output settings
- Output
Stream - Audio output settings for streaming TTS requests.
- Preset
Prompt - Preset-based emotion control for ssfm-v30 model
- Prompt
- Emotion settings for ssfm-v21 model
- Recommended
Voice - Voice recommendation result.
- Smart
Prompt - Context-aware emotion inference for ssfm-v30 model
- Subscription
Response - Response from
GET /v1/users/me/subscription - TTSRequest
- Text-to-Speech request parameters
- TTSRequest
Stream - Streaming Text-to-Speech request parameters.
- TTSResponse
- Text-to-Speech response
- VoiceV2
- Voice from V2 API with enhanced metadata
- Voices
V2Filter - Filter options for V2 voices endpoint
Enums
- Age
- Age group classification for voices
- Audio
Format - Audio output format
- Emotion
Preset - Emotion preset types for speech synthesis
- Gender
- Gender classification for voices
- Plan
Tier - Subscription plan tier
- TTSModel
- TTS model version to use for speech synthesis
- TTSPrompt
- Union type for all prompt types
- UseCase
- Voice use case categories
Constants
- CLONING_
MAX_ FILE_ SIZE - Maximum audio file size for voice cloning (25 MB)
- NAME_
MAX_ LENGTH - Maximum character length for a custom voice name
- NAME_
MIN_ LENGTH - Minimum character length for a custom voice name